@@ -21,7 +21,7 @@ print("\x1B[33m     \/     \/     \/      \/                   \/     \/
 print(" ")
 print("\x1b[37m [>] Library name: sendtomail")
 print("\x1b[37m [>] Developer: Misha Korzhik")
-time.sleep(0.4)
+time.sleep(0.3)
 
 class server:
     def send(region:str, email:str, *message:str):
@@ -50,7 +50,7 @@ class server:
         check = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
         check.connect((ip, port))
         check.sendall(bytes("free|check|ip|"+my_ip,'UTF-8')) #Checking IP for dangerousness
-        code = check.recv(1024)
+        code = check.recv(512)
         get = code.decode('utf-8')
         if get == "blacklisted": #Blacklisted IP
             return "Access denied, you ip address blacklisted!"+protected
@@ -67,10 +67,11 @@ class server:
                 check.sendall(bytes("smtp|"+region+"|"+email+"|"+message,'UTF-8'))
                 if debug == "on":
                    print("[98%] Data send to server")
-                code = check.recv(1024)
+                code = check.recv(512)
                 code = code.decode('utf-8')
                 check.shutdown(socket.SHUT_RDWR)
                 check.close()
+                time.sleep(float(cooldown))
                 return code
     def mail():
         if debug == "on":
@@ -169,7 +170,7 @@ class tempmail:
         check = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
         check.connect((ip, port))
         check.sendall(bytes("free|check|ip|"+my_ip,'UTF-8')) #Checking IP for dangerousness
-        code = check.recv(1024)
+        code = check.recv(512)
         get = code.decode('utf-8')
         if get == "blacklisted": #Blacklisted IP
             return "Access denied, you ip address blacklisted!"+protected
@@ -184,10 +185,11 @@ class tempmail:
                 check.sendall(bytes("free|tempmail|service|create",'UTF-8'))
                 if debug == "on":
                    print("[98%] Data send to server")
-                code = check.recv(4096)
+                code = check.recv(1024)
                 code = code.decode('utf-8')
                 check.shutdown(socket.SHUT_RDWR)
                 check.close()
+                time.sleep(float(cooldown))
                 return code
     def read(mail:str, domain:str):
         if debug == "on":
@@ -212,7 +214,7 @@ class tempmail:
         client.sendall(bytes("free|tempmail|"+mail+"|"+domain,'UTF-8'))
         if debug == "on":
             print("[80%] Feching data")
-        data = client.recv(1024)
+        data = client.recv(2048)
         if debug == "on":
             print("[97%] Getting data from server")
         data = data.decode('utf-8')
